﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

public class Player : MonoBehaviour
{
    public float speed;
    public float rotationSpeed;
    public float jumpHght;
    public float grav;
    bool jumping;
    bool moving;
    public AudioClip jumpSound;
    public AudioClip landSound;
    public AudioClip deathSound;
    private Rigidbody rb;

    void Start()
    {
        rb = GetComponent<Rigidbody>();
        Physics.gravity = new Vector3(0, grav, 0);
    }

    void FixedUpdate()
    {
        //Movement variables
        float v = Input.GetAxisRaw("Vertical") * speed;
        float h = Input.GetAxisRaw("Horizontal") * speed;
        float r = Input.GetAxisRaw("Mouse X") * rotationSpeed;
        v *= Time.deltaTime;
        h *= Time.deltaTime;
        r *= Time.deltaTime;

        //Rotates character/camera based on mouse movement.
        transform.Rotate(0, r, 0);

        //Moves character based on WASD/Left analog stick.
        rb.AddRelativeForce(0, 0, v, ForceMode.Impulse);
        rb.AddRelativeForce(h, 0, 0, ForceMode.Impulse);
    }

    void Update()
    {
        //Jumps, if character is not already in air.
        if (Input.GetButtonDown("Jump") && jumping == false)
        {
            rb.AddForce(new Vector3(0, jumpHght, 0), ForceMode.Impulse);
            GetComponent<AudioSource>().PlayOneShot(jumpSound);
        }
    }

    void OnCollisionEnter(Collision collision)
    {
        if(collision.gameObject.tag == "Wave")
        {
            Camera.main.transform.parent = null;
            AudioSource.PlayClipAtPoint(deathSound, Camera.main.transform.position, 5.0f);
            Destroy(gameObject);
        }

        if (collision.gameObject.tag == "Ground")
        {
            GetComponent<AudioSource>().PlayOneShot(landSound);
        }
    }

    //Determines when character is not in air.
    void OnCollisionStay(Collision collision)
    {
        jumping = false;
    }

    //Determines when character is in air.
    void OnCollisionExit(Collision collision)
    {
        if (!jumping)
        {
            jumping = true;
        }
    }
}
